@@ -86,6 +86,41 @@ def _qs_eval_helper(qs):
     # print strresult
     return strresult
 
+class IterableTest(TestCase):
+    def setUp(self):
+        super(IterableTest, self).setUp()
+        self.time = int(time.time() * 1000)
+
+    def test_iterable_render(self):
+        tmpl = BLANK % """
+        <xsl:copy-of select="xdjango:foo%d()"/>
+        """ % self.time
+        transformer = xslt.Transformer(tmpl)
+        
+        dictlist = [
+            {"a": 10, "b": 20, "c": 40},
+            {"a": 11, "b": 21, "c": 41},
+            {"a": 12, "b": 22, "c": 42},
+            ]
+
+        xmlobj = xsltmanagers.xmlifyiter(
+            dictlist,
+            "Simple",
+            attriba="a",
+            otherattrib="c"
+            )
+
+        # Use objects and NOT values
+        context_key = 'foo%d' % self.time
+        c = Context({ 
+                context_key: xmlobj,
+                })
+
+        res = transformer(context=c)
+        assertXpath(
+            res, 
+            '//simples/simple[@attriba="%s"]' % 10
+            )
 
 class QSRenderTestCase(TestCase):
     def setUp(self):
@@ -145,7 +180,7 @@ class QSRenderTestCase(TestCase):
         user.save()
 
         # Make a queryset
-        qs = User.objects.filter(username="user%s" % self.time),
+        qs = User.objects.filter(username="user%s" % self.time)
 
         # Make an xml object from it
         xml_list = xsltmanagers.xmlify(
@@ -159,7 +194,7 @@ class QSRenderTestCase(TestCase):
         res = transformer(context=c)
         assertXpath(
             res, 
-            '//users/user[@first_name="first%s"]' % self.time,
+            '//users//user[@first_name="first%s"]' % self.time,
             )
 
 
