@@ -2,5 +2,5 @@ from django.conf.urls.defaults import *
 
 urlpatterns = patterns(
     'djangoxslt.xslt.views',
-    url(r'^testtransform/(?P<page>[A-Z-a-z0-9_-]+)/$', 'page', {"namespace": "testtransform"}),
+    url(r'^testtransform/(?P<page>[A-Z-a-z0-9_-]+)/$', 'page', {"namespace": "testtransform_"}),
     )
